=========
Changelog
=========

----------------
0.2 - 2012-10-16
----------------

* Completing i18n coverage and added Italian support.  [giacomos]
* Added intermediate form class to eliminate the neeed to define wrapper
  classes for compatibility between Plone and z3c.form.

----------------
0.1 - 2011-10-20
----------------

* Provide the core functionality of OAuth into Zope/Plone, through the
  use of custom forms and the Pluggable Authentication System.
* Contain just the basic storage for all associated data types, but
  extensibility is allowed.
